—

# Delete account

By clicking on 'Delete account', your account will be permenantly deleted. This action is irreversable.

Please note that by deleting your account, also all your filled out surveys will be deleted. Please make sure to download your surveys from the reports screen prior to deleting your account if you want to keep any.

Your password for confirmation * Dit is een verplicht veld.

1. Voorbereiden
2. Inventariseren
3. Evalueren
4. Plan van aanpak
5. Rapporten

Link to sector organisation | Disclaimer | Design by Cornae